import QtQuick 1.1
import com.nokia.meego 1.0

Page {
	id: mainPage
    tools: commonTools
	orientationLock: PageOrientation.LockPortrait

	ToolBarLayout {
		id: commonTools
		visible: true

		BusyIndicator {
			anchors.horizontalCenter: refreshIcon.horizontalCenter
			visible: broker.searching
			running: broker.searching
		}
		ToolIcon {
			id: refreshIcon
			platformIconId: "toolbar-refresh"
			anchors.left: parent.left
			visible: !broker.searching
			onClicked: broker.refresh()
		}
		ToolIcon {
			platformIconId: "icon-m-content-description-inverse"
			anchors.right: parent.right
			onClicked: infoDialog.open()
		}
	}

	Column {
		anchors.fill: parent
		spacing: 20
		TextArea {
			id: quickGuide
			width: parent.width
			height: 380
			enabled: false
			readOnly: true
			text: "<h1>btinput</h1>" +
				  "<h2>Quick Guide</h2>" +
				  "<p>The list below shows available bluetooth devices. " +
				  "Select a bluetooth keyboard device you want connect to. " +
				  "Once connected you can unplug by clicking on it again. " +
				  "To refresh the list click on icon at the bottom-left.</p>" +
				  "<p><b>Remember to turn on bluetooth.</b></p>"
		}
		ListModel { id: nullModel }
		Connections {
			target: broker
			onDevicesChanged: {
				listView.model = nullModel
				listView.model = broker.deviceAddressList
			}
		}
		ListView {
			id: listView
			width: parent.width
			height: parent.height-430
			model: broker.deviceAddressList
			clip: true
			delegate: Rectangle {
				width: parent.width
				height: childrenRect.height
				id: listViewDelegate
				color: ((index&1) == 0) ? "#222222" : "transparent"
				Item {
					width: parent.width
					height: column.height

					Column {
						id: column
						Label { x: 10; text: broker.deviceName(modelData) !== "" ?
												 broker.deviceName(modelData) : "???" }
						Label { x: 10; text: modelData }
					}
					Image {
						id: connectedIndicator
						visible: broker.isConnected(modelData)
						source: "image://theme/icon-m-common-presence-online"
						anchors.right: parent.right
						anchors.rightMargin: 25
						anchors.verticalCenter: parent.verticalCenter
						scale: 0.5
					}
					BusyIndicator {
						visible: broker.isConnecting(modelData)
						running: broker.isConnecting(modelData)
						anchors.horizontalCenter: connectedIndicator.horizontalCenter
						anchors.verticalCenter: parent.verticalCenter
					}
				}
				MouseArea {
					id: mouseArea
					anchors.fill: parent
					onClicked: {
						if (broker.isConnected(modelData))
							broker.disconnectFrom(modelData)
						else
							broker.connectTo(modelData)
					}
				}
				states: [
					State {
						name: "mouseDown"
						when: mouseArea.containsMouse
						PropertyChanges {
							target: listViewDelegate
							color: "#2f6f88"
						}
					}
				]
			}
		}
	}

	Connections {
		target: broker
		onErrorOccured: {
			errorDialog.message = errorText
			errorDialog.open()
		}
	}

	QueryDialog {
		id: infoDialog
		titleText: "About"
		rejectButtonText: "Close"
		message:  "<h1>btinput 1.0.0</h1>" +
				  "<h3>Copyright 2012 (c) Marcin Kaźmierczak</h3>" +
				  "<p>TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, THIS SOFTWARE IS PROVIDED " +
				  "AS IS, WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, " +
				  "INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY " +
				  "AND/OR FITNESS FOR A PARTICULAR PURPOSE. THE AUTHORS SHALL NOT BE HELD " +
				  "LIABLE FOR ANY DAMAGE THAT MAY RESULT FROM THE USE OF THIS SOFTWARE. YOU USE " +
				  "THIS SOFTWARE ENTIRELY AT YOUR OWN RISK.\n\n" +
				  "Usage of this software indicates that you agree to the above conditions.</p>"
	}
	QueryDialog {
		id: errorDialog
		titleText: "Error"
		rejectButtonText: "Close"
	}
}
